@@ -40,19 +40,40 @@
 #' # download_assessment_list() and assessment_list_inventory().
 #'
 #' \donttest{
-#' ontario <- download_assessment_list(database = 2)
-#' ontario_invs <- assessment_list_inventory(ontario)
-#' ontario_summary <- assessment_cooccurrences_summary(ontario_invs)
+#' maine <- download_assessment_list(database = 56)
+#' maine_invs <- assessment_list_inventory(maine)
+#' maine_cooccurrences_summary <- assessment_cooccurrences_summary(maine_invs)
 #' }
 #'
 #' @export
 
+
 assessment_cooccurrences_summary <- function(inventory_list) {
+
+  bad_df <- data.frame(
+    target_species = character (0),
+    target_species_c = numeric(0),
+    target_species_nativity = character(0),
+    target_species_n = numeric(0),
+    cospecies_n = numeric(0),
+    cospecies_native_n = numeric(0),
+    cospecies_mean_c = numeric(0),
+    cospecies_native_mean_c = numeric(0),
+    cospecies_std_dev_c = numeric(0),
+    cospecies_native_std_dev_c = numeric(0),
+    percent_native = numeric(0),
+    percent_nonnative = numeric(0),
+    percent_native_low_c = numeric(0),
+    percent_native_med_c = numeric(0),
+    percent_native_high_c = numeric(0),
+    discrepancy_c = numeric(0)
+  )
+
   if (!is_inventory_list(inventory_list)) {
-    stop(
-      "assessment_list must be a list of dataframes obtained from universalFQA.org. Type ?download_assessment_list for help.",
-      call. = FALSE
+    message(
+      "assessment_list must be a list of inventories obtained from universalFQA.org. Type ?assessment_inventory_list for help."
     )
+    return(invisible(bad_df))
   }
 
   cooccur <- assessment_cooccurrences(inventory_list)
