@@ -32,7 +32,7 @@
 #'
 #' @examples
 #' \donttest{
-#' databases <- index_fqa_databases # Note database 1 is the original 1994 Chicago edition.
+#' databases <- index_fqa_databases() # Database 1 is the original 1994 Chicago edition.
 #' somme_assessments <- download_assessment_list(1, site == "Somme Woods")
 #' somme_summary <- assessment_list_glance(somme_assessments)
 #' }
@@ -44,8 +44,8 @@ download_assessment_list <- function(database_id, ...) {
 
   inventories_summary <- index_fqa_assessments(database_id)
 
-  if (is.null(inventories_summary)){
-    return(invisible(NULL))
+  if (nrow(inventories_summary) == 0){
+    return(list())
   }
 
   inventories_requested <- inventories_summary |>
