@@ -4,10 +4,10 @@ test_that("download_transect works", {
   expect_error(download_transect(2.5), "transect_id must be an integer.")
 
   null_output <- download_transect(-40000)
-  expect_null(null_output)
-  expect_equal(memoise::has_cache(download_transect_internal)(-40000), FALSE)
+  expect_equal(nrow(null_output), 0)
+  expect_false(memoise::has_cache(download_transect_internal)(-40000))
 
-  skip_on_cran()
+  skip_if_offline()
 
   expect_equal(ncol(download_transect(6322)), 14)
 })
