@@ -3,7 +3,12 @@ test_that("index_fqa_transects works", {
   expect_error(index_fqa_transects(1.5))
   expect_error(index_fqa_transects("hi"))
 
-  skip_on_cran()
+  empty_output <- index_fqa_transects(-40000)
+  expect_equal(nrow(empty_output), 0)
+  expect_equal(ncol(empty_output), 5)
+  expect_false(memoise::has_cache(index_fqa_transects_internal)(-40000))
+
+  skip_if_offline()
 
   transects <- index_fqa_transects(1)
 
