@@ -1,7 +1,11 @@
 test_that("transect_inventory works", {
 
-  expect_error(transect_inventory("hi"))
-  expect_error(transect_inventory(faithful))
+  expect_message(transect_inventory("hi"))
+  expect_message(transect_inventory(faithful))
+
+  blank <- suppressMessages(transect_inventory(faithful))
+  expect_equal(nrow(blank), 0)
+  expect_equal(ncol(blank), 13)
 
   test_manual <- transect_inventory(test_transect) #manual download
   expect_equal(ncol(test_manual), 13)
@@ -9,7 +13,7 @@ test_that("transect_inventory works", {
   expect_equal(typeof(test_manual[[5]]), "double")
   expect_equal(test_manual[[5]], 0)
 
-  skip_on_cran()
+  skip_if_offline()
 
   test_raw <- download_transect(4492) # normal database
   test <- transect_inventory(test_raw)
